@@ -30,7 +30,7 @@ class AuthConfig(BaseModel):
     ses_email_subject: str
     ses_from_email: EmailStr
     stage: str
-    allowed_email_domains: List[str]  # Email domains from which a user log in
+    allowed_email_domains: str  # Email domains from which a user log in, a column-separated string
 
 
 class AuthClients:
