@@ -517,8 +517,11 @@ class Auth:
             f"Email domain is not allowed for the email address: {email_address}"
         )
         try:
+            if self.config.allowed_email_domains == "*":
+                return True
+
+            allowed_email_domains = self.config.allowed_email_domains.split(",")
             email_domain = email_address.split("@")[-1]
-            allowed_email_domains = self.config.allowed_email_domains
             if email_domain in allowed_email_domains:
                 return True
             else:
